==> CDPKit-1.0.1.tar.gz: CDPKit-1.0.1/Doc/Doxygen/Python-API/Source/CDPL/Chem/BondConfiguration.doc.py <==
#
# This file is part of the Chemical Data Processing Toolkit
#
# Copyright (C) Thomas Seidel <thomas.seidel@univie.ac.at>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2 of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program; see the file COPYING. If not, write to
# the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
# Boston, MA 02111-1307, USA.
#

##
# \brief Provides constants that are used to specify the <em>E/Z</em> configuration of double bonds.
# 
class BondConfiguration(Boost.Python.instance):

    ##
    # \brief Specifies that the configuration of the bond is undefined.
    # 
    UNDEF = 0

    ##
    # \brief Specifies that a bond does not meet the requirements (e.g. not a double bond or symmetric) to be assigned a configuration.
    # 
    NONE = 1

    ##
    # \brief Specifies that the bond has <em>E</em> configuration.
    # 
    E = 2

    ##
    # \brief Specifies that the bond has <em>TRANS</em> configuration.
    # 
    TRANS = 2

    ##
    # \brief Specifies that the bond has <em>Z</em> configuration.
    # 
    Z = 4

    ##
    # \brief Specifies that the bond has <em>CIS</em> configuration.
    # 
    CIS = 4

    ##
    # \brief Specifies that the bond meets all requirements but has no defined configuration.
    # 
    EITHER = 8

==> CDPKit-1.1.0.tar.gz: CDPKit-1.1.0/Doc/Doxygen/Python-API/Source/CDPL/Chem/BondConfiguration.doc.py <==
#
# This file is part of the Chemical Data Processing Toolkit
#
# Copyright (C) Thomas Seidel <thomas.seidel@univie.ac.at>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2 of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program; see the file COPYING. If not, write to
# the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
# Boston, MA 02111-1307, USA.
#

##
# \brief Provides constants that are used to specify the <em>cis/trans</em> configuration of bonds.
# 
class BondConfiguration(Boost.Python.instance):

    ##
    # \brief Specifies that the configuration of the bond is completely undefined.
    # 
    UNDEF = 0

    ##
    # \brief Specifies that a bond does not meet the requirements to be assigned a configuration.
    # 
    NONE = 1

    ##
    # \brief Specifies that the bond has <em>trans</em> configuration.
    # 
    TRANS = 2

    ##
    # \brief Specifies that the bond has <em>cis</em> configuration.
    # 
    CIS = 4

    ##
    # \brief Specifies that the bond meets the requirements but has no defined configuration.
    # 
    EITHER = 8
